@@ -1,5 +1,5 @@
 # packages.sh
 #export PKG_<SCRIPTNAME>=<pkg URL>
 
-export PKG_BLFSSYSTEMD=https://www.linuxfromscratch.org/blfs/downloads/12.1-systemd/blfs-systemd-units-20240801.tar.xz
+export PKG_BLFSSYSTEMD=https://www.linuxfromscratch.org/blfs/downloads/systemd/blfs-systemd-units-20240801.tar.xz
 export PKG_BLFSBOOTSCRIPTS=https://anduin.linuxfromscratch.org/BLFS/blfs-bootscripts/blfs-bootscripts-20240416.tar.xz
